fix up classpaths in shell scripts

git-svn-id: https://svn.apache.org/repos/asf/xmlbeans/trunk@1867490 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/src/shell/_setlib b/src/shell/_setlib
index c3beccc..16fd307 100755
--- a/src/shell/_setlib
+++ b/src/shell/_setlib
@@ -20,13 +20,13 @@
 fi
 
 XMLBEANS_LIB=
-if [ -f "$XMLBEANS_HOME"/build/lib/xbean.jar ]; then
+if [ -f "$XMLBEANS_HOME"/build/lib/xmlbeans*.jar ]; then
     XMLBEANS_LIB=$XMLBEANS_HOME/build/lib
 fi
-if [ -f "$XMLBEANS_HOME"/lib/xbean.jar ]; then
+if [ -f "$XMLBEANS_HOME"/lib/xmlbeans*.jar ]; then
     XMLBEANS_LIB=$XMLBEANS_HOME/lib
 fi
 
 if [ -z "$XMLBEANS_LIB" ]; then
-    echo "ERROR: Could not find xbean.jar, try set XMLBEANS_LIB to the directory containing xbean.jar"
+    echo "ERROR: Could not find xmlbeans*.jar, try set XMLBEANS_LIB to the directory containing xmlbeans*.jar"
 fi
diff --git a/src/shell/_setlib.cmd b/src/shell/_setlib.cmd
index 6344731..c52209b 100644
--- a/src/shell/_setlib.cmd
+++ b/src/shell/_setlib.cmd
@@ -15,14 +15,14 @@
 @REM

 

 @rem Common script to set the XMLBEANS_LIB variable

-@rem to the directory containing xbean.jar

+@rem to the directory containing xmlbeans.jar

 @echo off

 

 if "%XMLBEANS_HOME%" EQU "" (set XMLBEANS_HOME=%~dp0..)

 

 set XMLBEANS_LIB=

 

-if exist "%XMLBEANS_HOME%\build\lib\xbean.jar" set XMLBEANS_LIB=%XMLBEANS_HOME%\build\lib

-if exist "%XMLBEANS_HOME%\lib\xbean.jar" set XMLBEANS_LIB=%XMLBEANS_HOME%\lib

+if exist "%XMLBEANS_HOME%\build\lib\xmlbeans*.jar" set XMLBEANS_LIB=%XMLBEANS_HOME%\build\lib

+if exist "%XMLBEANS_HOME%\lib\xmlbeans*.jar" set XMLBEANS_LIB=%XMLBEANS_HOME%\lib

 

-if "%XMLBEANS_LIB%" EQU "" echo "ERROR: Could not find xbean.jar, try setting XMLBEANS_LIB to the directory containing xbean.jar"

+if "%XMLBEANS_LIB%" EQU "" echo "ERROR: Could not find xmlbeans*.jar, try setting XMLBEANS_LIB to the directory containing xmlbeans*.jar"

diff --git a/src/shell/dumpxsb b/src/shell/dumpxsb
index 78ab292..9b60dcd 100755
--- a/src/shell/dumpxsb
+++ b/src/shell/dumpxsb
@@ -22,7 +22,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/dumpxsb.cmd b/src/shell/dumpxsb.cmd
index 39fb50b..6d2f910 100644
--- a/src/shell/dumpxsb.cmd
+++ b/src/shell/dumpxsb.cmd
@@ -23,7 +23,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar;%XMLBEANS_LIB%\jsr173_1.0_api.jar
+set cp=%cp%;%XMLBEANS_LIB%\*;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.XsbDumper %*
 
diff --git a/src/shell/inst2xsd b/src/shell/inst2xsd
index 9873954..9ab65cf 100755
--- a/src/shell/inst2xsd
+++ b/src/shell/inst2xsd
@@ -20,7 +20,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/inst2xsd.cmd b/src/shell/inst2xsd.cmd
index 9d1a3d8..da225c8 100644
--- a/src/shell/inst2xsd.cmd
+++ b/src/shell/inst2xsd.cmd
@@ -24,7 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 set cp=%cp%;%XMLBEANS_LIB%\resolver.jar
 
diff --git a/src/shell/scomp b/src/shell/scomp
index 68d29b1..9906132 100755
--- a/src/shell/scomp
+++ b/src/shell/scomp
@@ -20,7 +20,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar:$JAVA_HOME/lib/tools.jar:$XMLBEANS_LIB/resolver.jar
+cp=$XMLBEANS_LIB/*:$JAVA_HOME/lib/tools.jar
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/scomp.cmd b/src/shell/scomp.cmd
index e82a9e8..1681f7b 100644
--- a/src/shell/scomp.cmd
+++ b/src/shell/scomp.cmd
@@ -24,8 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar
-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 set cp=%cp%;%JAVA_HOME%\lib\tools.jar
 set cp=%cp%;%XMLBEANS_LIB%\resolver.jar
diff --git a/src/shell/scopy.cmd b/src/shell/scopy.cmd
index ff68c31..9006b51 100644
--- a/src/shell/scopy.cmd
+++ b/src/shell/scopy.cmd
@@ -24,7 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar;%XMLBEANS_LIB%\jsr173_1.0_api.jar
+set cp=%cp%;%XMLBEANS_LIB%\*;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.SchemaCopy %*
 
diff --git a/src/shell/sdownload b/src/shell/sdownload
index 118c717..49ebde7 100755
--- a/src/shell/sdownload
+++ b/src/shell/sdownload
@@ -20,7 +20,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/sdownload.cmd b/src/shell/sdownload.cmd
index 3d2b603..eaa1b54 100644
--- a/src/shell/sdownload.cmd
+++ b/src/shell/sdownload.cmd
@@ -24,8 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar
-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 set cp=%cp%;%XMLBEANS_LIB%\resolver.jar
 
diff --git a/src/shell/sfactor b/src/shell/sfactor
index 0554b5e..a4f078f 100755
--- a/src/shell/sfactor
+++ b/src/shell/sfactor
@@ -22,7 +22,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar:$XMLBEANS_LIB/resolver.jar
+cp=$XMLBEANS_LIB/*:$XMLBEANS_LIB/resolver.jar
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/sfactor.cmd b/src/shell/sfactor.cmd
index 27c6321..4d00d91 100644
--- a/src/shell/sfactor.cmd
+++ b/src/shell/sfactor.cmd
@@ -24,7 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar;%XMLBEANS_LIB%\jsr173_1.0_api.jar;%XMLBEANS_LIB%\resolver.jar;
+set cp=%cp%;%XMLBEANS_LIB%\*;%XMLBEANS_LIB%\jsr173_1.0_api.jar;%XMLBEANS_LIB%\resolver.jar;
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.FactorImports %*
 
diff --git a/src/shell/svalidate b/src/shell/svalidate
index 13a6ad6..b4b60c4 100755
--- a/src/shell/svalidate
+++ b/src/shell/svalidate
@@ -21,7 +21,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar:$XMLBEANS_LIB/jsr173_1.0_ri.jar
+cp=$XMLBEANS_LIB/*:$XMLBEANS_LIB/jsr173_1.0_ri.jar
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/svalidate.cmd b/src/shell/svalidate.cmd
index 551a952..e5dde53 100644
--- a/src/shell/svalidate.cmd
+++ b/src/shell/svalidate.cmd
@@ -24,8 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar
-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_ri.jar
 
diff --git a/src/shell/validate b/src/shell/validate
index 62a75fa..7e3b8d5 100755
--- a/src/shell/validate
+++ b/src/shell/validate
@@ -21,7 +21,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/validate.cmd b/src/shell/validate.cmd
index d2fc318..32efc26 100644
--- a/src/shell/validate.cmd
+++ b/src/shell/validate.cmd
@@ -24,8 +24,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar
-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.InstanceValidator %*
diff --git a/src/shell/xpretty b/src/shell/xpretty
index 2deb8c6..001349b 100755
--- a/src/shell/xpretty
+++ b/src/shell/xpretty
@@ -19,7 +19,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/xpretty.cmd b/src/shell/xpretty.cmd
index aa1f581..ec379c0 100644
--- a/src/shell/xpretty.cmd
+++ b/src/shell/xpretty.cmd
@@ -22,6 +22,6 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar;%XMLBEANS_LIB%\jsr173_1.0_api.jar
+set cp=%cp%;%XMLBEANS_LIB%\*;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.PrettyPrinter %*
diff --git a/src/shell/xsd2inst b/src/shell/xsd2inst
index c3e43f4..b1ea81f 100755
--- a/src/shell/xsd2inst
+++ b/src/shell/xsd2inst
@@ -19,7 +19,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/xsd2inst.cmd b/src/shell/xsd2inst.cmd
index a1a3d48..7ece129 100644
--- a/src/shell/xsd2inst.cmd
+++ b/src/shell/xsd2inst.cmd
@@ -23,8 +23,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"

 

 set cp=

-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar

-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar

+set cp=%cp%;%XMLBEANS_LIB%\*

 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar

 

 java -classpath "%cp%" org.apache.xmlbeans.impl.xsd2inst.SchemaInstanceGenerator %*

diff --git a/src/shell/xsdtree b/src/shell/xsdtree
index 03e140b..1962369 100755
--- a/src/shell/xsdtree
+++ b/src/shell/xsdtree
@@ -19,7 +19,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar
+cp=$XMLBEANS_LIB/*
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/xsdtree.cmd b/src/shell/xsdtree.cmd
index 7ec0497..01cdd79 100644
--- a/src/shell/xsdtree.cmd
+++ b/src/shell/xsdtree.cmd
@@ -22,6 +22,6 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar;%XMLBEANS_LIB%\xmlbeans-qname.jar;%XMLBEANS_LIB%\jsr173_1.0_api.jar;
+set cp=%cp%;%XMLBEANS_LIB%\*;%XMLBEANS_LIB%\jsr173_1.0_api.jar;
 
 java -classpath "%cp%" org.apache.xmlbeans.impl.tool.TypeHierarchyPrinter %*
diff --git a/src/shell/xstc b/src/shell/xstc
index 80abf1c..7daf0d8 100755
--- a/src/shell/xstc
+++ b/src/shell/xstc
@@ -19,7 +19,7 @@
 
 if [ -z "$XMLBEANS_LIB" ]; then . `dirname $0`/_setlib; fi
 
-cp=$XMLBEANS_LIB/xbean.jar:$XMLBEANS_LIB/xmlbeans-qname.jar:$XMLBEANS_LIB/jsr173_1.0_api.jar:$XMLBEANS_LIB/resolver.jar
+cp=$XMLBEANS_LIB/*:$XMLBEANS_LIB/resolver.jar
 
 case "`uname`" in
     CYGWIN*)
diff --git a/src/shell/xstc.cmd b/src/shell/xstc.cmd
index f024a5a..b5ef780 100644
--- a/src/shell/xstc.cmd
+++ b/src/shell/xstc.cmd
@@ -22,8 +22,7 @@
 if "%XMLBEANS_LIB%" EQU "" call "%~dp0_setlib"
 
 set cp=
-set cp=%cp%;%XMLBEANS_LIB%\xbean.jar
-set cp=%cp%;%XMLBEANS_LIB%\xmlbeans-qname.jar
+set cp=%cp%;%XMLBEANS_LIB%\*
 set cp=%cp%;%XMLBEANS_LIB%\jsr173_1.0_api.jar
 set cp=%cp%;%XMLBEANS_LIB%\resolver.jar
 
diff --git a/src/xmlpublic/org/apache/xmlbeans/XmlBeans.java b/src/xmlpublic/org/apache/xmlbeans/XmlBeans.java
index 05929f3..0104416 100644
--- a/src/xmlpublic/org/apache/xmlbeans/XmlBeans.java
+++ b/src/xmlpublic/org/apache/xmlbeans/XmlBeans.java
@@ -167,7 +167,7 @@
             throw causedException(
                 new IllegalStateException(
                     "Cannot load constructor for " + className +
-                ": verify that xbean.jar is on the classpath" ), e );
+                ": verify that xmlbeans.jar is on the classpath" ), e );
         }
     }
 
@@ -185,7 +185,7 @@
             throw causedException(
                 new IllegalStateException(
                     "Cannot load " + methodName +
-                        ": verify that xbean.jar is on the classpath" ), e );
+                        ": verify that xmlbeans.jar is on the classpath" ), e );
         }
     }
 
@@ -332,7 +332,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.getContextTypeLoader(): verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.getContextTypeLoader(): verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -355,7 +355,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to BuiltinSchemaTypeSystem.get(): verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to BuiltinSchemaTypeSystem.get(): verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -379,7 +379,7 @@
         {
             throw causedException(
                 new IllegalStateException(
-                    "No access to nodeToCursor verify that version of xbean.jar is correct" ), e );
+                    "No access to nodeToCursor verify that version of xmlbeans.jar is correct" ), e );
         }
         catch ( InvocationTargetException e )
         {
@@ -403,7 +403,7 @@
         {
             throw causedException(
                 new IllegalStateException(
-                    "No access to nodeToXmlObject verify that version of xbean.jar is correct" ), e );
+                    "No access to nodeToXmlObject verify that version of xmlbeans.jar is correct" ), e );
         }
         catch ( InvocationTargetException e )
         {
@@ -427,7 +427,7 @@
         {
             throw causedException(
                 new IllegalStateException(
-                    "No access to nodeToXmlStreamReader verify that version of xbean.jar is correct" ), e );
+                    "No access to nodeToXmlStreamReader verify that version of xmlbeans.jar is correct" ), e );
         }
         catch ( InvocationTargetException e )
         {
@@ -451,7 +451,7 @@
         {
             throw causedException(
                 new IllegalStateException(
-                    "No access to streamToNode verify that version of xbean.jar is correct" ), e );
+                    "No access to streamToNode verify that version of xmlbeans.jar is correct" ), e );
         }
         catch ( InvocationTargetException e )
         {
@@ -513,7 +513,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.forSchemaXml(): verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.forSchemaXml(): verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -672,7 +672,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw new IllegalStateException("No access to SchemaTypeLoaderImpl.forSchemaXml(): verify that version of xbean.jar is correct");
+            throw new IllegalStateException("No access to SchemaTypeLoaderImpl.forSchemaXml(): verify that version of xmlbeans.jar is correct");
         }
         catch (InvocationTargetException e)
         {
@@ -697,7 +697,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -720,7 +720,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -745,7 +745,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -779,7 +779,7 @@
                 throw new RuntimeException("SchemaTypeSystem is null for field " +
                     TYPE_SYSTEM_FIELD + " on class with name " + stsName +
                     "." + HOLDER_CLASS_NAME +
-                    ". Please verify the version of xbean.jar is correct.");
+                    ". Please verify the version of xmlbeans.jar is correct.");
             }
             return sts;
         }
@@ -793,19 +793,19 @@
         {
             throw causedException(new RuntimeException("Cannot find field " +
                 TYPE_SYSTEM_FIELD + " on class " + stsName + "." + HOLDER_CLASS_NAME +
-                ". Please verify the version of xbean.jar is correct."), e);
+                ". Please verify the version of xmlbeans.jar is correct."), e);
         }
         catch (IllegalAccessException e)
         {
             throw causedException(new RuntimeException("Field " +
                 TYPE_SYSTEM_FIELD + " on class " + stsName + "." + HOLDER_CLASS_NAME +
-                "is not accessible. Please verify the version of xbean.jar is correct."), e);
+                "is not accessible. Please verify the version of xmlbeans.jar is correct."), e);
         }
     }
 
     /**
      * Returns a new ResourceLoader for a search path where each component of
      * the path is either a directory or a compiled xbean jar.
      */
     public static ResourceLoader resourceLoaderForPath(File[] path)
     {
@@ -815,7 +815,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl: verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InstantiationException e)
         {
@@ -862,7 +862,7 @@
         }
         catch (IllegalAccessException e)
         {
-            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.getContextTypeLoader(): verify that version of xbean.jar is correct"), e);
+            throw causedException(new IllegalStateException("No access to SchemaTypeLoaderImpl.getContextTypeLoader(): verify that version of xmlbeans.jar is correct"), e);
         }
         catch (InvocationTargetException e)
         {
@@ -793,19 +793,19 @@
     /**
      * Returns a new ResourceLoader for a search path where each component of
-     * the path is either a directory or a compiled xbean jar.
+     * the path is either a directory or a compiled xmlbeans jar.
      */
     public static ResourceLoader resourceLoaderForPath(File[] path)